==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1ReplicaSetFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1beta1ReplicaSetFluent<A extends V1beta1ReplicaSetFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1beta1ReplicaSetFluent.MetadataNested<A> withNewMetadata();
    public V1beta1ReplicaSetFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1beta1ReplicaSetFluent.MetadataNested<A> editMetadata();
    public V1beta1ReplicaSetFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1ReplicaSetFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1ReplicaSetSpec getSpec();
    public V1beta1ReplicaSetSpec buildSpec();
    public A withSpec(V1beta1ReplicaSetSpec spec);
    public Boolean hasSpec();
    public V1beta1ReplicaSetFluent.SpecNested<A> withNewSpec();
    public V1beta1ReplicaSetFluent.SpecNested<A> withNewSpecLike(V1beta1ReplicaSetSpec item);
    public V1beta1ReplicaSetFluent.SpecNested<A> editSpec();
    public V1beta1ReplicaSetFluent.SpecNested<A> editOrNewSpec();
    public V1beta1ReplicaSetFluent.SpecNested<A> editOrNewSpecLike(V1beta1ReplicaSetSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1ReplicaSetStatus getStatus();
    public V1beta1ReplicaSetStatus buildStatus();
    public A withStatus(V1beta1ReplicaSetStatus status);
    public Boolean hasStatus();
    public V1beta1ReplicaSetFluent.StatusNested<A> withNewStatus();
    public V1beta1ReplicaSetFluent.StatusNested<A> withNewStatusLike(V1beta1ReplicaSetStatus item);
    public V1beta1ReplicaSetFluent.StatusNested<A> editStatus();
    public V1beta1ReplicaSetFluent.StatusNested<A> editOrNewStatus();
    public V1beta1ReplicaSetFluent.StatusNested<A> editOrNewStatusLike(V1beta1ReplicaSetStatus item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1beta1ReplicaSetFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1ReplicaSetSpecFluent<V1beta1ReplicaSetFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1ReplicaSetStatusFluent<V1beta1ReplicaSetFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1ReplicaSetFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1beta1ReplicaSetFluent<A extends V1beta1ReplicaSetFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1beta1ReplicaSetFluent.MetadataNested<A> withNewMetadata();
    public V1beta1ReplicaSetFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1beta1ReplicaSetFluent.MetadataNested<A> editMetadata();
    public V1beta1ReplicaSetFluent.MetadataNested<A> editOrNewMetadata();
    public V1beta1ReplicaSetFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1ReplicaSetSpec getSpec();
    public V1beta1ReplicaSetSpec buildSpec();
    public A withSpec(V1beta1ReplicaSetSpec spec);
    public Boolean hasSpec();
    public V1beta1ReplicaSetFluent.SpecNested<A> withNewSpec();
    public V1beta1ReplicaSetFluent.SpecNested<A> withNewSpecLike(V1beta1ReplicaSetSpec item);
    public V1beta1ReplicaSetFluent.SpecNested<A> editSpec();
    public V1beta1ReplicaSetFluent.SpecNested<A> editOrNewSpec();
    public V1beta1ReplicaSetFluent.SpecNested<A> editOrNewSpecLike(V1beta1ReplicaSetSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1ReplicaSetStatus getStatus();
    public V1beta1ReplicaSetStatus buildStatus();
    public A withStatus(V1beta1ReplicaSetStatus status);
    public Boolean hasStatus();
    public V1beta1ReplicaSetFluent.StatusNested<A> withNewStatus();
    public V1beta1ReplicaSetFluent.StatusNested<A> withNewStatusLike(V1beta1ReplicaSetStatus item);
    public V1beta1ReplicaSetFluent.StatusNested<A> editStatus();
    public V1beta1ReplicaSetFluent.StatusNested<A> editOrNewStatus();
    public V1beta1ReplicaSetFluent.StatusNested<A> editOrNewStatusLike(V1beta1ReplicaSetStatus item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1beta1ReplicaSetFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1ReplicaSetSpecFluent<V1beta1ReplicaSetFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1ReplicaSetStatusFluent<V1beta1ReplicaSetFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}
